Coverage report

# Coverage report: 89%

Hot-keys on this page

n s m x c change column sorting

Module | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
Total | 997 | 108 | 20 | 89%
pandalone/components.py | 71 | 2 | 6 | 97%
pandalone/mappings.py | 336 | 3 | 2 | 99%
pandalone/pandata.py | 431 | 68 | 12 | 84%
pandalone/xleash/_parse.py | 158 | 35 | 0 | 78%
pandalone/xleash/io/__init__.py | 1 | 0 | 0 | 100%

No items found using the specified filter.